@@ -185,7 +185,7 @@ use Data::Dumper;
 use base 'Exporter';
 use v5.14;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 our @EXPORT = qw{
 	one_row
@@ -1371,7 +1371,7 @@ sub _build_complex_query {
 	}
 	my $from = '';
 	@columns = ('*') if not @columns;
-	@columns = map {('SCALAR' eq ref) ? DBIx::Struct::connect->dbh->quote_identifier($_) : $_} @columns;
+	@columns = map {('SCALAR' eq ref) ? DBIx::Struct::connect->dbh->quote_identifier($$_) : $_} @columns;
 	my $joined = 0;
 	for (my $idx = 0; $idx < @from; ++$idx) {
 		if (not $joined) {
